@@ -4,19 +4,21 @@ Many docstrings in this file are based on PEP-249, which is in the public domain
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
+
+import abc
+import collections
+import datetime
+import logging
+import time
 from builtins import bytes
 from builtins import int
 from builtins import object
 from builtins import str
-from past.builtins import basestring
-import abc
-import collections
-import time
-import datetime
+
 from future.utils import with_metaclass
-from itertools import islice
+from past.builtins import basestring
+
 from e6xdb.exceptions import ProgrammingError
-import logging
 
 _logger = logging.getLogger(__name__)
 
@@ -33,6 +35,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         self._reset_state()
         self.lastrowid = None
         self._data = None
+        self._query_id = None
 
     def _reset_state(self):
         """Reset state about the previous query in preparation for running another query"""
@@ -42,6 +45,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         # Internal helper state
         self._data = collections.deque()
         self._columns = None
+        self._query_id = None
 
     def _fetch_while(self, fn):
         _logger.info("Commons - fetch while.... fn type - {}".format(type(fn)))
