@@ -214,7 +214,6 @@ class Cursor(DBAPICursor):
         self._data = None
         self._query_columns_description = None
         self._description = None
-        self._query_id = None
         self._batch = list()
         self._rowcount = 0
 
@@ -295,7 +294,7 @@ class Cursor(DBAPICursor):
 
     def cancel(self, query_id):
         _logger.info("Cancelling query")
-        self.connection.query_cancel(query_id)
+        self.connection.query_cancel(self._query_id)
 
     def execute(self, operation, parameters=None, **kwargs):
         """Prepare and execute a database operation (query or command).
@@ -422,6 +421,7 @@ class Error(Exception):
     pass
 
 
+<<<<<<< Updated upstream
 # if __name__ == '__main__':
 #     e6x_connection = connect(host="e6data-cls6-rj7u4l-042347692bba1a38.elb.us-east-1.amazonaws.com",
 #                          port=9000,
@@ -453,6 +453,63 @@ class Error(Exception):
 #     # cursor.close()
 #
 #     e6x_connection.close()
+=======
+if __name__ == '__main__':
+    connection = connect(host="localhost",
+                         port=9000,
+                         scheme="e6xdb",
+                         username="admin",
+                         database="tpcds_10gb",
+                         auth=None,
+                         configuration=None,
+                         kerberos_service_name=None,
+                         password="admin",
+                         check_hostname=None,
+                         ssl_cert=None,
+                         thrift_transport=None)
+    cursor = Cursor(connection)
+    cursor.execute("select * from store_sales LEFT OUTER JOIN store_returns ON (sr_item_sk = ss_item_sk AND sr_ticket_number = ss_ticket_number);")
+    bdata = []
+    try:
+        for i in range(1000):
+            cursor.cancel(None)
+            bdata += cursor.fetchmany()
+        print('total rows in the batch resultset ', len(bdata))
+        r_count = cursor.rowcount()
+        print('total row count', r_count)
+    except Exception as e:
+        print('Error Message ', e.__cause__)
+
+    while True:
+        try:
+            connection = connect(host="localhost",
+                                 port=9000,
+                                 scheme="e6xdb",
+                                 username="admin",
+                                 database="tpcds_10gb",
+                                 auth=None,
+                                 configuration=None,
+                                 kerberos_service_name=None,
+                                 password="admin",
+                                 check_hostname=None,
+                                 ssl_cert=None,
+                                 thrift_transport=None)
+            cursor = Cursor(connection)
+            isOpen = cursor.connection.check_connection
+            if not isOpen:
+                time.sleep(5)
+                continue
+            else:
+                break
+        except:
+            time.sleep(5)
+            continue
+
+    cursor.execute("SELECT * from catalog_sales limit 100;")
+    bdata = []
+    for i in range(1000):
+        bdata += cursor.fetchmany()
+>>>>>>> Stashed changes
 
 #
 # Type Objects and Constructors
